.. _vmware_rest_scenarios:

****************************
VMware REST Scenarios
****************************

The content on this page has moved to :ref:`ansible_collections.vmware.vmware_rest.docsite.guide_vmware_rest`.
